package com.vendor.burn.model.devices.burners;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.Messages;
import com.vendor.burn.model.BurnContext;
import com.vendor.burn.model.ChipID;
import com.vendor.burn.model.FileSystem;
import com.vendor.burn.model.FlashType;
import com.vendor.burn.model.PlatformType;
import com.vendor.burn.model.TransferWay;
import com.vendor.burn.model.UploadOption;
import com.vendor.burn.model.define.IBurner;
import com.vendor.burn.model.define.IFastbootProgressMonitor;
import com.vendor.burn.model.devices.IAddressBurner;
import com.vendor.burn.model.devices.ITab;
import com.vendor.burn.model.devices.burners.FastbootBurner;
import com.vendor.burn.model.event.EventType;
import com.vendor.burn.model.event.FastbootEvent;
import com.vendor.burn.preferences.FastbootPreferences;
import com.vendor.burn.serial.workers.AbstractBurnerWorker;
import com.vendor.burn.serial.workers.AddressBurnerWorker;
import com.vendor.burn.ui.UploadOptionDialog;
import com.vendor.burn.ui.burners.tabs.AddressTab;
import com.vendor.burn.utilitily.ToolUtils;
import com.vendor.burn.views.FastbootView;
import java.io.File;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.List;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.jobs.IJobChangeListener;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.osgi.util.NLS;
import org.eclipse.swt.widgets.Display;
import org.vendor.tftp.tool.TFTPService;

public class AddressBurner extends FastbootBurner implements IAddressBurner {
  private UploadOption uploadOption = null;
  
  private String address;
  
  private String length;
  
  private ChipID chipId;
  
  private FileSystem fileSystem = FileSystem.none;
  
  protected AddressBurnerWorker worker = null;
  
  public AddressBurner(BurnContext burnContext) {
    super(burnContext);
  }
  
  public void burn(IFastbootProgressMonitor fastbootMonitor) {
    if (fastbootMonitor == null)
      return; 
    fastbootMonitor.getEvent().init(EventType.BURN);
    FlashType flashType = getFlashType();
    AddressBurnerWorker worker = getBurnerWorker();
    worker.setProgressMonitor(fastbootMonitor);
    worker.setFlashType(flashType);
    File file = new File(getFile());
    TransferWay transferWay = getBurnContext().getTransferWay();
    if (worker.isNeedSetupNet(transferWay)) {
      File home = new File(file.getParent());
      boolean start = false;
      InetAddress address = null;
      try {
        address = InetAddress.getByName("x.x.x.x");
      } catch (UnknownHostException unknownHostException) {}
      int port = FastbootPreferences.getInt("vendor.burn.tftp.port");
      try {
        start = TFTPService.TFTPSERVICE.start(home, address, ToolUtils.getPortCmd(), port);
        getTftpPreferenceValue();
      } catch (Exception e) {
        handleTftpStartFailed();
      } finally {
        if (!start)
          fastbootMonitor
            .warnln(Messages.PartitionBurner_msg_start_Tftp_server_failed_on_port_69); 
      } 
    } 
    if (fastbootMonitor != null) {
      FastbootEvent event = fastbootMonitor.getEvent();
      Object object = new Object(this, "Burn By Address", fastbootMonitor, transferWay, worker, file, event);
      showProgressDialog((Job)object);
      object.addJobChangeListener((IJobChangeListener)new Object(this, fastbootMonitor));
      object.schedule();
    } 
  }
  
  protected AddressBurnerWorker getBurnerWorker() {
    if (this.worker == null)
      this.worker = new AddressBurnerWorker((IBurner)this); 
    return this.worker;
  }
  
  public IStatus checkBeforeBurn() {
    return check(EventType.BURN);
  }
  
  protected IStatus check(EventType type) {
    if (getFlashType() == null)
      return error(Messages.AddressBurner_msg_please_select_the_flash_type); 
    String file = getFile();
    if ((type == EventType.BURN || type == EventType.UPLOAD) && (
      file == null || file.trim().length() == 0))
      return error(Messages.AbstractBurner_msg_file_path_does_not_select); 
    if (type != null && 
      type.name().equalsIgnoreCase("BURN")) {
      File theFile = new File(file);
      if (!theFile.exists())
        return error(Messages.AbstractBurner_msg_the_file_does_not_exist); 
      if (0 == file.length())
        return error(Messages.AbstractBurner_msg_the_file_size_must_be_nonzero); 
    } 
    if (EventType.BURN == type)
      return checkBurn(); 
    if (EventType.UPLOAD == type)
      return checkUpload(); 
    if (EventType.ERASE == type)
      return checkErase(); 
    return null;
  }
  
  private IStatus checkErase() {
    IStatus validLocalConfig = validSerialPort();
    if (!isOK(validLocalConfig))
      return validLocalConfig; 
    boolean addrVaild = (getAddress() == null || getAddress().length() == 0);
    if (addrVaild)
      return error(NLS.bind(Messages.AddressBurner_msg_please_input_address, Messages.BurnComposite_Erase_Text)); 
    boolean lenVaild = (getLength() == null || getLength().length() == 0 || Long.parseLong(getLength(), 16) < 1L);
    if (lenVaild)
      return error(NLS.bind(Messages.AddressBurner_msg_please_input_length, Messages.BurnComposite_Erase_Text)); 
    if ((getProgrammerFile() == null || getProgrammerFile().trim()
      .equals("")) && 
      getBurnContext().getPlatformType() == PlatformType.CA)
      return error(Messages.AddressBurner_No_Programmer_File); 
    return null;
  }
  
  private IStatus checkUpload() {
    IStatus validNetConfig = validNetConfig();
    if (!isOK(validNetConfig))
      return validNetConfig; 
    boolean isVaildAddr = (getAddress() == null || getAddress().length() == 0);
    if (isVaildAddr)
      return error(NLS.bind(Messages.AddressBurner_msg_please_input_address, Messages.BurnComposite_Upload_Text)); 
    boolean isVaildLen = (getLength() == null || getLength().length() == 0 || Long.parseLong(getLength(), 16) < 1L);
    if (isVaildLen)
      return error(NLS.bind(Messages.AddressBurner_msg_please_input_length, Messages.BurnComposite_Upload_Text)); 
    long uploadLen = Long.parseLong(getLength(), 16);
    if (uploadLen % 1024L != 0L)
      return error(Messages.AddressBurner_msg_input_length_align); 
    boolean isVaildFile = (getFile() == null || getFile().equals(""));
    if (isVaildFile)
      return error(NLS.bind(Messages.AddressBurner_msg_please_select_the_file_to_, Messages.BurnComposite_Upload_Text)); 
    boolean isVaildProgrammerFile = ((getProgrammerFile() == null || getProgrammerFile().trim().equals("")) && getBurnContext().getPlatformType() == PlatformType.CA);
    if (isVaildProgrammerFile)
      return error(Messages.AddressBurner_No_Programmer_File); 
    try {
      File file = new File(getFile());
      if (file.exists()) {
        boolean openConfirm = MessageDialog.openQuestion(
            Display.getDefault().getActiveShell(), Messages.FASTBOOT_CONFIRM_Title, 
            
            NLS.bind(Messages.PartitionComposite_msg_file_exists_already_whether_to_overwrite_it, file
              
              .getCanonicalPath()));
        if (!openConfirm)
          return Status.CANCEL_STATUS; 
      } 
      boolean tftpFileNameVaild = (getBurnContext().getTransferWay() == TransferWay.Net && (file.getName().getBytes(
          System.getProperty("file.encoding"))).length > 100);
      if (tftpFileNameVaild)
        return error(Messages.msg_File_name_is_too_long_please_use_a_short_name_instead); 
    } catch (IOException iOException) {}
    return null;
  }
  
  private IStatus checkBurn() {
    IStatus validNetConfig = validNetConfig();
    if (!isOK(validNetConfig))
      return validNetConfig; 
    boolean isVaildAddr = (getAddress() == null || getAddress().length() == 0);
    if (isVaildAddr)
      return error(NLS.bind(Messages.AddressBurner_msg_please_input_address, Messages.BurnComposite_Burn_Text)); 
    boolean isVaildFile = (getFile() == null || getFile().trim().equals(""));
    if (isVaildFile)
      return error(NLS.bind(Messages.AddressBurner_msg_please_select_the_file_to_, Messages.BurnComposite_Burn_Text)); 
    boolean isVaildProgrammerFile = ((getProgrammerFile() == null || getProgrammerFile().trim().equals("")) && getBurnContext().getPlatformType() == PlatformType.CA);
    if (isVaildProgrammerFile)
      return error(Messages.AddressBurner_No_Programmer_File); 
    File file = new File(getFile());
    boolean fileExists = (!file.exists() || file.isDirectory());
    if (fileExists)
      return error(Messages.AddressBurner_msg_file_does_not_exist_or_is_a_directory); 
    boolean yaffsFile = true;
    try {
      yaffsFile = FileSystem.isYaffsFile((IBurner)this, file);
    } catch (IOException e1) {
      return error(Messages.AddressBurner_msg_exception_occurs_while_reading_the_file_please_try_again);
    } 
    FileSystem curFileSystem = yaffsFile ? FileSystem.yaffs : FileSystem.none;
    setFileSystem(curFileSystem);
    boolean spiYaffs = (FlashType.spi == getFlashType() && yaffsFile);
    if (spiYaffs)
      return error(Messages.AddressBurner_msg_invalid_file_for_the_flash_is_SPI_but_the_file_is_a_Yaffs_type_file); 
    try {
      boolean tftpFileNameVaild = ((getBurnContext().getTransferWay() == TransferWay.Net || getBurnContext().getTransferWay() == TransferWay.UsbTransNet || getBurnContext().getTransferWay() == TransferWay.JTAGAndNet) && (file.getName().getBytes(
          System.getProperty("file.encoding"))).length > 100);
      if (tftpFileNameVaild)
        return error(Messages.msg_File_name_is_too_long_please_use_a_short_name_instead); 
    } catch (UnsupportedEncodingException unsupportedEncodingException) {}
    return null;
  }
  
  public IStatus checkBeforeErase() {
    return check(EventType.ERASE);
  }
  
  public IStatus checkBeforeUpload() {
    IStatus upload = check(EventType.UPLOAD);
    if (!isOK(upload))
      return upload; 
    if ((getBurnContext().getTransferWay() == TransferWay.USBBootrom && !FastbootView.isChipBranchSeries9()) || 
      getBurnContext().getTransferWay() == TransferWay.USBNonNude || 
      getBurnContext().getTransferWay() == TransferWay.UsbAndSerial)
      return error(NLS.bind(Messages.AddressComposite_Current_NotSupport_Upload, "USB")); 
    if (getBurnContext().getTransferWay() == TransferWay.I2CBootrom)
      return error(NLS.bind(Messages.AddressComposite_Current_NotSupport_Upload, "I2C")); 
    if (getBurnContext().getTransferWay() == TransferWay.Serial)
      return error(NLS.bind(Messages.AddressComposite_Current_NotSupport_Upload, Messages.FastbootView_TransferWay_Serial)); 
    FlashType flashType = getFlashType();
    if (FlashType.nand == flashType) {
      UploadOptionDialog optionDialog = new UploadOptionDialog(Display.getDefault().getActiveShell());
      optionDialog.setUploadOption(UploadOption.DATA_NO_OOB);
      int open = optionDialog.open();
      if (open == 0) {
        this.uploadOption = optionDialog.getUploadOption();
      } else {
        return (IStatus)new Status(8, "com.vendor.burn", "Upload Cancelled!");
      } 
    } 
    return null;
  }
  
  public void erase(IFastbootProgressMonitor fastbootMonitor) {
    AddressBurnerWorker worker = getBurnerWorker();
    BurnContext context = getBurnContext();
    worker.setProgressMonitor(fastbootMonitor);
    worker.setFlashType(getFlashType());
    if (fastbootMonitor != null) {
      FastbootEvent event = fastbootMonitor.getEvent();
      if (event != null) {
        Object object = new Object(this, "Erase By Address", fastbootMonitor, context, worker, event);
        showProgressDialog((Job)object);
        object.addJobChangeListener((IJobChangeListener)new Object(this, fastbootMonitor));
        object.schedule();
      } 
    } 
  }
  
  public String getLength() {
    return this.length;
  }
  
  public List<String> getSteps() {
    List<String> steps = new ArrayList<>();
    steps.add(Messages.AddressBurner_Step_1);
    steps.add(Messages.AddressBurner_Step_2);
    steps.add(Messages.AddressBurner_Step_3);
    steps.add(Messages.AddressBurner_Step_4);
    steps.add(Messages.AddressBurner_Step_5);
    steps.add(Messages.AddressBurner_Step_6);
    return steps;
  }
  
  public void setLength(String length) {
    this.length = length;
  }
  
  public void upload(IFastbootProgressMonitor fastbootMonitor) {
    String filePath = getFile();
    if (filePath == null)
      return; 
    File file = new File(filePath);
    AddressBurnerWorker worker = getBurnerWorker();
    worker.setProgressMonitor(fastbootMonitor);
    worker.setFlashType(getFlashType());
    File home = new File(file.getParent());
    if (fastbootMonitor != null && 
      fastbootMonitor.getEvent() != null)
      fastbootMonitor.getEvent().setBurner((IBurner)this); 
    boolean start = false;
    InetAddress address = null;
    try {
      address = InetAddress.getByName("x.x.x.x");
    } catch (UnknownHostException unknownHostException) {}
    int port = FastbootPreferences.getInt("vendor.burn.tftp.port");
    try {
      start = TFTPService.TFTPSERVICE.start(home, address, ToolUtils.getPortCmd(), port);
      getTftpPreferenceValue();
      getBurnContext().setTftpOccupied(!start);
    } catch (Exception e) {
      getBurnContext().setTftpOccupied(true);
      handleTftpStartFailed();
    } finally {
      if (!start && 
        fastbootMonitor != null)
        fastbootMonitor
          .warnln(Messages.PartitionBurner_msg_start_Tftp_server_failed_on_port_69); 
    } 
    if (fastbootMonitor != null) {
      FastbootEvent event = fastbootMonitor.getEvent();
      Object object = new Object(this, "Upload By Address", fastbootMonitor, worker, file, event);
      showProgressDialog((Job)object);
      object.addJobChangeListener((IJobChangeListener)new Object(this, fastbootMonitor));
      object.schedule();
    } 
  }
  
  public ChipID getCurrentChipId() {
    return ChipID.chip0;
  }
  
  public FileSystem getFileSystem() {
    return this.fileSystem;
  }
  
  public void setFileSystem(FileSystem fileSystem) {
    this.fileSystem = fileSystem;
  }
  
  public String getAddress() {
    return this.address;
  }
  
  public void setAddress(String address) {
    this.address = address;
  }
  
  public ChipID getChipID() {
    return this.chipId;
  }
  
  public void setFlashId(ChipID chipId) {
    this.chipId = chipId;
  }
  
  public ITab getTab() {
    return (ITab)new AddressTab();
  }
  
  public void eraseAll(IFastbootProgressMonitor monitor) {}
}
